/*
 * Copyright (C) 2013 Jolla Ltd.
 * Contact: Lucien Xu <lucien.xu@jollamobile.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "keyproviderhelper.h"
#include <MGConfItem>

KeyProviderHelper::KeyProviderHelper(QObject *parent)
    : QObject(parent)
    , m_triedLoadingFacebook(false)
    , m_triedLoadingTwitter(false)
    , m_triedLoadingOneDrive(false)
    , m_triedLoadingDropbox(false)
    , m_triedLoadingVk(false)
{
}

QString KeyProviderHelper::dropboxClientId()
{
    if (!m_triedLoadingDropbox) {
        loadDropbox();
    }

    return m_dropboxClientId;
}

void KeyProviderHelper::loadDropbox()
{
    m_triedLoadingDropbox = true;
    QString cClientId = MGConfItem(QStringLiteral("/socialcache/keys/dropbox/client_id")).value(0).toString();
    if (cClientId.isEmpty()) {
        return;
    }

    m_dropboxClientId = cClientId;
}

QString KeyProviderHelper::facebookClientId()
{
    if (!m_triedLoadingFacebook) {
        loadFacebook();
    }

    return m_facebookClientId;
}

QString KeyProviderHelper::twitterConsumerKey()
{
    if (!m_triedLoadingTwitter) {
        loadTwitter();
    }

    return m_twitterConsumerKey;
}

QString KeyProviderHelper::twitterConsumerSecret()
{
    if (!m_triedLoadingTwitter) {
        loadTwitter();
    }

    return m_twitterConsumerSecret;
}

QString KeyProviderHelper::oneDriveClientId()
{
    if (!m_triedLoadingOneDrive) {
        loadOneDrive();
    }

    return m_oneDriveClientId;
}

QString KeyProviderHelper::vkClientId()
{
    if (!m_triedLoadingVk) {
        loadVk();
    }

    return m_vkClientId;
}

void KeyProviderHelper::loadFacebook()
{
    m_triedLoadingFacebook = true;
    QString cClientId = MGConfItem(QStringLiteral("/socialcache/keys/facebook/client_id")).value(0).toString();

    if (cClientId.isEmpty()) {
        return;
    }

    m_facebookClientId = cClientId;
}

void KeyProviderHelper::loadTwitter()
{
    m_triedLoadingTwitter = true;
    QString cConsumerKey = MGConfItem(QStringLiteral("/socialcache/keys/twitter/consumer_key")).value(0).toString();
    QString cConsumerSecret = MGConfItem(QStringLiteral("/socialcache/keys/twitter/consumer_secret")).value(0).toString();

    if (cConsumerKey.isEmpty() || cConsumerSecret.isEmpty()) {
        return;
    }

    m_twitterConsumerKey = cConsumerKey;
    m_twitterConsumerSecret = cConsumerSecret;
}

void KeyProviderHelper::loadOneDrive()
{
    m_triedLoadingOneDrive = true;
    QString cClientId = MGConfItem(QStringLiteral("/socialcache/keys/onedrive/client_id")).value(0).toString();
    if (cClientId.isEmpty()) {
        return;
    }

    m_oneDriveClientId = cClientId;
}

void KeyProviderHelper::loadVk()
{
    m_triedLoadingVk = true;
    QString cClientId = MGConfItem(QStringLiteral("/socialcache/keys/vk/client_id")).value(0).toString();

    if (cClientId.isEmpty()) {
        return;
    }

    m_vkClientId = cClientId;
}
